@@ -137,11 +137,7 @@ wbWorksheet <- R6::R6Class(
 
     #' @description
     #' Creates a new `wbWorksheet` object
-    #' @param gridLines gridLines
-    #' @param rowColHeaders rowColHeaders
-    #' @param tabSelected tabSelected
     #' @param tabColour tabColour
-    #' @param zoom zoom
     #' @param oddHeader oddHeader
     #' @param oddFooter oddFooter
     #' @param evenHeader evenHeader
@@ -152,13 +148,10 @@ wbWorksheet <- R6::R6Class(
     #' @param orientation orientation
     #' @param hdpi hdpi
     #' @param vdpi vdpi
+    #' @param printGridLines printGridLines
     #' @return a `wbWorksheet` object
     initialize = function(
-      gridLines   = TRUE,
-      rowColHeaders = TRUE,
-      tabSelected = FALSE,
       tabColour   = NULL,
-      zoom        = 100,
       oddHeader   = NULL,
       oddFooter   = NULL,
       evenHeader  = NULL,
@@ -168,7 +161,8 @@ wbWorksheet <- R6::R6Class(
       paperSize   = 9,
       orientation = "portrait",
       hdpi        = 300,
-      vdpi        = 300
+      vdpi        = 300,
+      printGridLines = FALSE
     ) {
       if (!is.null(tabColour)) {
         tabColour <- sprintf('<sheetPr><tabColor rgb="%s"/></sheetPr>', tabColour)
@@ -176,12 +170,6 @@ wbWorksheet <- R6::R6Class(
         tabColour <- character()
       }
 
-      if (zoom < 10) {
-        zoom <- 10
-      } else if (zoom > 400) {
-        zoom <- 400
-      }
-
       hf <- list(
         oddHeader   = na_to_null(oddHeader),
         oddFooter   = na_to_null(oddFooter),
@@ -195,10 +183,15 @@ wbWorksheet <- R6::R6Class(
         hf <- list()
       }
 
+      # only add if printGridLines not TRUE. The openxml default is TRUE
+      if (printGridLines) {
+       self$set_print_options(gridLines = printGridLines, gridLinesSet = printGridLines)
+      }
+
       ## list of all possible children
       self$sheetPr               <- tabColour
       self$dimension             <- '<dimension ref="A1"/>'
-      self$sheetViews            <- sprintf('<sheetViews><sheetView workbookViewId="0" zoomScale="%s" showGridLines="%s" showRowColHeaders="%s" tabSelected="%s"/></sheetViews>', as.integer(zoom), as.integer(gridLines), as.integer(rowColHeaders), as.integer(tabSelected))
+      self$sheetViews            <- character()
       self$sheetFormatPr         <- '<sheetFormatPr baseColWidth="8.43" defaultRowHeight="16" x14ac:dyDescent="0.2"/>'
       self$cols_attr             <- character()
       self$autoFilter            <- character()
@@ -231,19 +224,28 @@ wbWorksheet <- R6::R6Class(
         '<worksheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:xdr="http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing" xmlns:x14="http://schemas.microsoft.com/office/spreadsheetml/2009/9/main" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" mc:Ignorable="x14ac xr xr2 xr3" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac" xmlns:xr="http://schemas.microsoft.com/office/spreadsheetml/2014/revision" xmlns:xr2="http://schemas.microsoft.com/office/spreadsheetml/2015/revision2" xmlns:xr3="http://schemas.microsoft.com/office/spreadsheetml/2016/revision3">',
 
         # sheetPr
-        if (length(self$sheetPr) && !any(grepl("<sheetPr>", self$sheetPr, fixed = TRUE))) {
-          paste0("<sheetPr>", paste(self$sheetPr, collapse = ""), "</sheetPr>")
+        if (length(self$sheetPr) && !any(xml_node_name(self$sheetPr) == "sheetPr")) {
+          xml_node_create("sheetPr", xml_children = self$sheetPr)
         } else {
           self$sheetPr
         },
 
         self$dimension,
 
-        if (length(self$freezePane)) {
-          gsub("/></sheetViews>", paste0(">", self$freezePane, "</sheetView></sheetViews>"), self$sheetViews, fixed = TRUE)
-        } else if (length(self$sheetViews)) {
+        if (length(self$freezePane) && length(self$sheetViews)) {
+          # get sheetView node and append freezePane
+          # TODO is this extracted correctly? Can we unfreeze a pane?
+          sheetView <- xml_node(self$sheetView, "sheetViews", "sheetView")
+          sheetView <- xml_add_child(sheetView, xml_child = self$freezePane)
+
+          # return the xml node
+          xml_node_create("sheetViews", sheetView)
+        },
+
+        if (length(self$sheetViews)) {
           self$sheetViews
         },
+
         self$sheetFormatPr,
         # cols_attr
         # is this fine if it's just <cols></cols>?
@@ -319,6 +321,7 @@ wbWorksheet <- R6::R6Class(
           )
         },
 
+        self$printOptions,
         self$pageMargins,
         self$pageSetup,
 
@@ -510,6 +513,32 @@ wbWorksheet <- R6::R6Class(
       invisible(self)
     },
 
+    #' @description add print options
+    #' @param gridLines gridLines
+    #' @param gridLinesSet gridLinesSet
+    #' @param headings If TRUE prints row and column headings
+    #' @param horizontalCentered If TRUE the page is horizontally centered
+    #' @param verticalCentered If TRUE the page is vertically centered
+    #' @returns The `wbWorksheet` object
+    set_print_options = function(
+        gridLines          = NULL,
+        gridLinesSet       = NULL,
+        headings           = NULL,
+        horizontalCentered = NULL,
+        verticalCentered   = NULL
+    ) {
+      self$printOptions <- xml_node_create(
+        xml_name = "printOptions",
+        xml_attributes = c(
+          gridLines          = as_xml_attr(gridLines),
+          gridLinesSet       = as_xml_attr(gridLinesSet),
+          headings           = as_xml_attr(headings),
+          horizontalCentered = as_xml_attr(horizontalCentered),
+          verticalCentered   = as_xml_attr(verticalCentered)
+        )
+      )
+    },
+
     #' @description append a field.  Intended for internal use only.  Not
     #'   guaranteed to remain a public method.
     #' @param field a field name
@@ -529,6 +558,90 @@ wbWorksheet <- R6::R6Class(
 
       private$do_append_x14(sparklines, "x14:sparklineGroup", "x14:sparklineGroups")
 
+      invisible(self)
+    },
+
+    #' @description add sheetview
+    #' @param colorId colorId
+    #' @param defaultGridColor defaultGridColor
+    #' @param rightToLeft rightToLeft
+    #' @param showFormulas showFormulas
+    #' @param showGridLines showGridLines
+    #' @param showOutlineSymbols showOutlineSymbols
+    #' @param showRowColHeaders showRowColHeaders
+    #' @param showRuler showRuler
+    #' @param showWhiteSpace showWhiteSpace
+    #' @param showZeros showZeros
+    #' @param tabSelected tabSelected
+    #' @param topLeftCell topLeftCell
+    #' @param view view
+    #' @param windowProtection windowProtection
+    #' @param workbookViewId workbookViewId
+    #' @param zoomScale zoomScale
+    #' @param zoomScaleNormal zoomScaleNormal
+    #' @param zoomScalePageLayoutView zoomScalePageLayoutView
+    #' @param zoomScaleSheetLayoutView zoomScaleSheetLayoutView
+    #' @return The `wbWorksheetObject`, invisibly
+    set_sheetview = function(
+      colorId                  = NULL,
+      defaultGridColor         = NULL,
+      rightToLeft              = NULL,
+      showFormulas             = NULL,
+      showGridLines            = NULL,
+      showOutlineSymbols       = NULL,
+      showRowColHeaders        = NULL,
+      showRuler                = NULL,
+      showWhiteSpace           = NULL,
+      showZeros                = NULL,
+      tabSelected              = NULL,
+      topLeftCell              = NULL,
+      view                     = NULL,
+      windowProtection         = NULL,
+      workbookViewId           = NULL,
+      zoomScale                = NULL,
+      zoomScaleNormal          = NULL,
+      zoomScalePageLayoutView  = NULL,
+      zoomScaleSheetLayoutView = NULL
+    ) {
+
+      # all zoom scales must be in the range of 10 - 400
+
+      # get existing sheetView
+      sheetView <- xml_node(self$sheetViews, "sheetViews", "sheetView")
+
+      if (length(sheetView) == 0)
+        sheetView <- xml_node_create("sheetView")
+
+      sheetView <- xml_attr_mod(
+        sheetView,
+        xml_attributes = c(
+          colorId                  = as_xml_attr(colorId),
+          defaultGridColor         = as_xml_attr(defaultGridColor),
+          rightToLeft              = as_xml_attr(rightToLeft),
+          showFormulas             = as_xml_attr(showFormulas),
+          showGridLines            = as_xml_attr(showGridLines),
+          showOutlineSymbols       = as_xml_attr(showOutlineSymbols),
+          showRowColHeaders        = as_xml_attr(showRowColHeaders),
+          showRuler                = as_xml_attr(showRuler),
+          showWhiteSpace           = as_xml_attr(showWhiteSpace),
+          showZeros                = as_xml_attr(showZeros),
+          tabSelected              = as_xml_attr(tabSelected),
+          topLeftCell              = as_xml_attr(topLeftCell),
+          view                     = as_xml_attr(view),
+          windowProtection         = as_xml_attr(windowProtection),
+          workbookViewId           = as_xml_attr(workbookViewId),
+          zoomScale                = as_xml_attr(zoomScale),
+          zoomScaleNormal          = as_xml_attr(zoomScaleNormal),
+          zoomScalePageLayoutView  = as_xml_attr(zoomScalePageLayoutView),
+          zoomScaleSheetLayoutView = as_xml_attr(zoomScaleSheetLayoutView)
+        )
+      )
+
+      self$sheetViews <- xml_node_create(
+        "sheetViews",
+        xml_children = sheetView
+      )
+
       invisible(self)
     }
   ),
