@@ -1,9 +1,3 @@
-test_that("names.wbWorkbook is deprecated", {
-  wb <- wb_workbook()$add_worksheet(1)
-  expect_warning(names(wb), "deprecated")
-  expect_warning({names(wb) <- 1}, "deprecated") # nolint
-})
-
 test_that("names", {
   tmp <- temp_xlsx()
 
